@@ -1,12 +1,18 @@
 HiJACK<-function(lps, sta, vel)
 {
 
-
+#########  lps is a list of earthquake event pickfiles
+#######     each element is an individual pickfile
+####   with elements STAS that contain station names, arival times
+####   sta is a list of station locations
+####   vel is a 1D velocity model used for relocation
   BSI = vector(mode="list")
 
   for(ipi in 1:length(lps))
     {
-      g1 = RSEIS::getpfile(lps[ipi], stafile = NULL)
+###  g1 = RSEIS::getpfile(lps[ipi], stafile = NULL)
+
+        g1 = lps[[ipi]]
 
       MA = match(g1$STAS$name, sta$name)
 
