@@ -24,7 +24,7 @@ PCfiledatetime<-function (orgtim, tims)
                               flag = "0"))
   amcrsec = formatC(as.integer(mymcrsec), width = 6, flag = "0")
   charvec = paste(sep="_", gdates, gtimes, amcrsec)
-  cat(charvec, sep = "\n")
+  message(charvec )
   
   return( charvec[which.min(tims)] )
 }
