@@ -12,8 +12,8 @@ Pick3<-function(nh, g)
 
               ipick = ipick[length(ipick)]
               
-             ## cat(paste(sep=" ", ypick, ipick), sep="\n")
-             ## print(ipick)
+             ## message(paste(sep=" ", ypick, ipick), sep="\n")
+             ## message(ipick)
               ##
               
               ma = which(!is.na(match( nh$STNS, nh$STNS[ipick])))
@@ -29,7 +29,7 @@ Pick3<-function(nh, g)
               ma = ma[order(icomp)]
 
               
-####  print(cbind(nh$STNS[ma], nh$COMPS[ma]))
+####  message(cbind(nh$STNS[ma], nh$COMPS[ma]))
 
               
               if(is.null(g$Pickdev))
@@ -71,15 +71,15 @@ Pick3<-function(nh, g)
               stit = nh$STNS[ma[1]]
               ##  SWP = selAPX(WPX,  nh$STNS[ma[1]], icomp=NULL )
 
-              ##   print(data.frame(SWP))
+              ##   message(data.frame(SWP))
               ##   SWP = rectifyAPX(SWP)
               ##
-              ## print(SWP)
+              ## message(SWP)
 
               
               newpicks = RSEIS::swig(nh, APIX=g$WPX, sel=ma, WIN=pickwin,
                 STDLAB=PICKLAB ,PADDLAB=PLAB, PHASE=1   ,
-                SHOWONLY = FALSE, TIT=stit)
+                SHOWONLY = FALSE, TIT=stit , destdir=g$destdir)
 
 
               
@@ -93,9 +93,9 @@ Pick3<-function(nh, g)
               ##  
               
               ##
-####    print(cbind(WPX$name, WPX$comp, WPX$phase, WPX$onoff))
+####    message(cbind(WPX$name, WPX$comp, WPX$phase, WPX$onoff))
               g$NPX = length(g$WPX$name)
-####                print(paste(sep=' ', "DONE with PICKWIN", g$NPX))
+####                message(paste(sep=' ', "DONE with PICKWIN", g$NPX))
               dev.set( g$MAINdev)
 
               
