@@ -6,21 +6,16 @@ SaveCSV <-
     
     twpx= g$WPX
 
-  ##   print("SaveCSV test")
-  ##   print(twpx$sec)
-  ##   print(data.frame(twpx))
+  ##   message("SaveCSV test")
+  ##   message(twpx$sec)
+  ##   message(data.frame(twpx))
 
     if( identical(legitWPX(twpx, quiet=FALSE),0)  ) {
 
-      cat("Need to click on screen, register picks (GPIX, or YPIX)", sep="\n")
+      message("Need to click on screen, register picks (GPIX, or YPIX)" )
     }
     else
       {
-
-
-        ##  print("SaveCSV it is going here")
-
-        
         nona = which( is.na(twpx$tag) )
         
         if(length(nona)>0)
@@ -41,7 +36,14 @@ SaveCSV <-
         fout2 = paste(fout1,"csv", sep="." )
         
         ##      fout3 = paste(destdir, fout2, sep="/")
-
+        if(is.null(g$destdir)) {
+           
+            destdir=tempdir()
+             message(paste('Writing output to ', destdir) )
+        }
+           
+        fout2 = paste(g$destdir, fout2, sep="/")
+        
         write.csv(twpx, file=fout2)
         g$LWPX = twpx
         g$WPX = RSEIS::cleanWPX()
