@@ -2,16 +2,24 @@ SavePF <-
 function(nh, g )
   {
     
-    
+      if(is.null(g$destdir)) {
+          destdir=tempdir()
+          message(paste('Writing output to ', destdir) )
+      }
+      else
+      {
+          destdir =  g$destdir
+      }
+      
     if(is.null(nh$pickfile))
       {
-        print("SavePF: saving raw pix")
+        message("SavePF: saving raw pix")
 
 
 
         if( identical(legitWPX(g$WPX),0)  ) {
           
-          cat("Need to click on screen, register picks (GPIX, or YPIX)", sep="\n")
+          message("Need to click on screen, register picks (GPIX, or YPIX)", sep="\n")
         }
         else
           {
@@ -25,7 +33,7 @@ function(nh, g )
                 twpx = RSEIS::deleteWPX(twpx, nona)
               }
             
-            PCsaveWPX(twpx, destdir="." )
+            PCsaveWPX(twpx, destdir=destdir )
           }
         
       }
@@ -34,21 +42,21 @@ function(nh, g )
 
         if(is.null( nh$sta))
           {
-            print("no station file")
+            warning("no station file")
             invisible(list(global.vars=g))
           }
         
     
         if( all(is.na( nh$sta)) )
           {
-            print("no station file")
+            warning("no station file")
             invisible(list(global.vars=g))
           }
     
         
         
         
-        PFoutput(nh$pickfile, nh$sta,  sol=NULL, format=c(1,2) )
+        PFoutput(nh$pickfile, nh$sta,  sol=NULL, format=c(1,2), destdir=destdir  )
       }
     
     
