@@ -36,7 +36,7 @@ Vlocate<-function(Ldat,EQ,vel,
 ###########   Earthquake location starting guess
     if(is.na(EQ$lat))
       {
-        cat("Guess at first arrival station", sep="\n" )
+        message("Guess at first arrival station", sep="\n" )
         
         wstart = which.min(Ldat$sec)
         EQ = list(lat=Ldat$lat[wstart], lon=Ldat$lon[wstart], z=6, t=Ldat$sec[wstart]-1)
@@ -48,12 +48,12 @@ Vlocate<-function(Ldat,EQ,vel,
         EQ$y = eqxy$y
       }
 
-    if( !checkLOCATEinput(Ldat, EQ) ) { cat(' Vlocate has bad/missing data.\n') ;  return(NULL) }
+    if( !checkLOCATEinput(Ldat, EQ) ) { warning(' Vlocate has bad/missing data.\n') ;  return(NULL) }
 ################### crude estimate  iterations  
 
 ###     /* fix depth for initial entry to locath */
   ###    maxITER = 7
-###print(EQ)
+###message(EQ)
     AQ = XYlocate(Ldat,EQ,vel, 
       maxITER = maxITER[1],
       distwt = distwt,
