@@ -5,8 +5,8 @@ checkLOCATEinput<-function(Ldat, EQ, vel=NULL)
          any( !is.numeric(Ldat$y) ) |
          any( !is.numeric(Ldat$z) ) )
           {
-              cat('STOP:\n')
-              cat(' Ldat has bad data.\n')
+              message('STOP:\n')
+              warning(' Ldat has bad data.\n')
               return(FALSE)
           }
 
@@ -16,8 +16,8 @@ checkLOCATEinput<-function(Ldat, EQ, vel=NULL)
          any( !is.numeric(EQ$t) )
          )
           {
-              cat('STOP:\n')
-              cat(' EQ has bad/missing data.\n')
+              message('STOP:\n')
+              warning(' EQ has bad/missing data.\n')
               return(FALSE)
           }
 
