@@ -7,7 +7,8 @@ clusterWPX<-function(twpx, tol=200, PLOT=FALSE)
 
 ####     if all the pix are within tol, just return
 
-####jj  = RSEIS::swig(GH, sel=GH$COMPS=="V", PADDLAB="YPIX" ); twpx = jj$g$WPX
+####jj  = RSEIS::swig(GH, sel=GH$COMPS=="V", PADDLAB="YPIX", destdir="." );
+      ##    twpx = jj$g$WPX
     ##  clusterWPX(twpx)
     
 
@@ -30,7 +31,7 @@ clusterWPX<-function(twpx, tol=200, PLOT=FALSE)
 
     
 ###    H2 = hclust(D1)
-    H2 = hclust(D1,  method = "ward" )
+    H2 = hclust(D1,  method = "ward.D" )
 
     b = boxplot(H2$height, plot=FALSE)
 
@@ -67,7 +68,7 @@ clusterWPX<-function(twpx, tol=200, PLOT=FALSE)
         
         KL[[i]] = twpx[wj,]
 
-##### saveWPX(clusx, destdir="." )
+#####MAY want to save this: saveWPX
 
       }
 
