@@ -127,15 +127,15 @@ eqwrapup<-function(Ldat,
     Q1 = Q1,
     Q2 = Q2)
   
-  ##  print(data.frame(giveback))
+  ##  message(data.frame(giveback))
   
   if(verbose)
     {
-      cat(paste("rms = ", format(rms)) , sep="\n")
-      cat(paste("dx = ", format(dels[2])) , sep="\n")
-      cat(paste("dy = ", format(dels[3])) , sep="\n")
-      cat(paste("dz = ", format(dels[4])) , sep="\n")
-      cat(paste("Quality:", Q1, Q2), sep="\n")
+      message(paste("rms = ", format(rms)) , sep="\n")
+      message(paste("dx = ", format(dels[2])) , sep="\n")
+      message(paste("dy = ", format(dels[3])) , sep="\n")
+      message(paste("dz = ", format(dels[4])) , sep="\n")
+      message(paste("Quality:", Q1, Q2), sep="\n")
     }
 
   return(giveback)
