@@ -2,13 +2,11 @@ gMAP <-
 function(nh, g, idev=3)
   {
 
-    
-    
     Apf =  nh$pickfile
 
     if(is.null(Apf))
       {
-        print("gMAP: no pickfile")
+        warning("gMAP: no pickfile")
         dev.set( g$MAINdev)
         return()
       }
@@ -32,12 +30,12 @@ function(nh, g, idev=3)
     pcols  = g$pcols[colmatch]
     
     
-    print("DOING MAP")
+    message("DOING MAP")
 
 
     dev.set( dev.next() )
 
-    print(sta)
+    message(sta)
     
     gproj = doAmap(sta)
     
