@@ -13,7 +13,7 @@ lastPIX<-function(nh, g )
     
     if( identical(legitWPX(g$LWPX, quiet=FALSE),0)  ) {
       
-      cat("No saved Picks", sep="\n")
+      warning("No saved Picks", sep="\n")
     }
     else
       {
